==> jc-1.4.0.tar.gz: java/awt/SystemColor.h <==
// public final class java.awt.SystemColor

// class file dependencies
// @dep_class 2110d2173833fd4f java_awt_Color
// @dep_class d23b12b037835f06 java_awt_SystemColor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Color

#include "java/awt/Color.h"

#ifndef _JC_java_awt_SystemColor_H_
#define _JC_java_awt_SystemColor_H_

// Forward structure declarations
struct _jc_java_awt_PaintContext$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_SystemColor$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_SystemColor$sub_refs	_jc_java_awt_SystemColor$sub_refs;
typedef struct _jc_java_awt_SystemColor$sub_nonrefs	_jc_java_awt_SystemColor$sub_nonrefs;
typedef struct _jc_java_awt_SystemColor$refs	_jc_java_awt_SystemColor$refs;
typedef struct _jc_java_awt_SystemColor$nonrefs	_jc_java_awt_SystemColor$nonrefs;
typedef struct _jc_java_awt_SystemColor$object	_jc_java_awt_SystemColor$object;

typedef struct _jc_java_awt_SystemColor$fields_struct	_jc_java_awt_SystemColor$fields_struct;
typedef const struct _jc_java_awt_SystemColor$vmethods	_jc_java_awt_SystemColor$vmethods;
typedef const struct _jc_java_awt_SystemColor$vtable	_jc_java_awt_SystemColor$vtable;
typedef const struct _jc_java_awt_SystemColor$vtype	_jc_java_awt_SystemColor$vtype;

// Class fields structure
struct _jc_java_awt_SystemColor$fields_struct {
	struct _jc_java_awt_SystemColor$object	*activeCaption;
	struct _jc_java_awt_SystemColor$object	*activeCaptionBorder;
	struct _jc_java_awt_SystemColor$object	*activeCaptionText;
	_jc_int_array	*colors;
	struct _jc_java_awt_SystemColor$object	*control;
	struct _jc_java_awt_SystemColor$object	*controlDkShadow;
	struct _jc_java_awt_SystemColor$object	*controlHighlight;
	struct _jc_java_awt_SystemColor$object	*controlLtHighlight;
	struct _jc_java_awt_SystemColor$object	*controlShadow;
	struct _jc_java_awt_SystemColor$object	*controlText;
	struct _jc_java_awt_SystemColor$object	*desktop;
	struct _jc_java_awt_SystemColor$object	*inactiveCaption;
	struct _jc_java_awt_SystemColor$object	*inactiveCaptionBorder;
	struct _jc_java_awt_SystemColor$object	*inactiveCaptionText;
	struct _jc_java_awt_SystemColor$object	*info;
	struct _jc_java_awt_SystemColor$object	*infoText;
	struct _jc_java_awt_SystemColor$object	*menu;
	struct _jc_java_awt_SystemColor$object	*menuText;
	struct _jc_java_awt_SystemColor$object	*scrollbar;
	struct _jc_java_awt_SystemColor$object	*text;
	struct _jc_java_awt_SystemColor$object	*textHighlight;
	struct _jc_java_awt_SystemColor$object	*textHighlightText;
	struct _jc_java_awt_SystemColor$object	*textInactiveText;
	struct _jc_java_awt_SystemColor$object	*textText;
	struct _jc_java_awt_SystemColor$object	*window;
	struct _jc_java_awt_SystemColor$object	*windowBorder;
	struct _jc_java_awt_SystemColor$object	*windowText;
	jlong	serialVersionUID;
	jint	ACTIVE__5fCAPTION;
	jint	ACTIVE__5fCAPTION__5fBORDER;
	jint	ACTIVE__5fCAPTION__5fTEXT;
	jint	CONTROL;
	jint	CONTROL__5fDK__5fSHADOW;
	jint	CONTROL__5fHIGHLIGHT;
	jint	CONTROL__5fLT__5fHIGHLIGHT;
	jint	CONTROL__5fSHADOW;
	jint	CONTROL__5fTEXT;
	jint	DESKTOP;
	jint	INACTIVE__5fCAPTION;
	jint	INACTIVE__5fCAPTION__5fBORDER;
	jint	INACTIVE__5fCAPTION__5fTEXT;
	jint	INFO;
	jint	INFO__5fTEXT;
	jint	MENU;
	jint	MENU__5fTEXT;
	jint	NUM__5fCOLORS;
	jint	SCROLLBAR;
	jint	TEXT;
	jint	TEXT__5fHIGHLIGHT;
	jint	TEXT__5fHIGHLIGHT__5fTEXT;
	jint	TEXT__5fINACTIVE__5fTEXT;
	jint	TEXT__5fTEXT;
	jint	WINDOW;
	jint	WINDOW__5fBORDER;
	jint	WINDOW__5fTEXT;
};
extern _jc_java_awt_SystemColor$fields_struct _jc_java_awt_SystemColor$class_fields;

// Constructors
extern void _jc_java_awt_SystemColor$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_SystemColor$object *, jint);

// Virtual methods
extern struct _jc_object *_jc_java_awt_SystemColor$method$createContext$a690f44ea9ada11b(_jc_env *, struct _jc_java_awt_SystemColor$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *);
extern jint _jc_java_awt_SystemColor$method$getRGB$2afffecc5c382bc6(_jc_env *, struct _jc_java_awt_SystemColor$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_SystemColor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_SystemColor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_SystemColor$method_info$createContext$a690f44ea9ada11b;
extern _jc_method _jc_java_awt_SystemColor$method_info$getRGB$2afffecc5c382bc6;
extern _jc_method _jc_java_awt_SystemColor$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_awt_SystemColor$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_SystemColor$vmethods {
	struct _jc_object	*(*createContext$a690f44ea9ada11b)(_jc_env *, struct _jc_java_awt_SystemColor$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *);
	jint	(*getRGB$2afffecc5c382bc6)(_jc_env *, struct _jc_java_awt_SystemColor$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_SystemColor$object *);
};

// Vtable
struct _jc_java_awt_SystemColor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Color$vmethods	java_awt_Color;
	_jc_java_awt_SystemColor$vmethods	java_awt_SystemColor;
};

// Vtype
struct _jc_java_awt_SystemColor$vtype {
	_jc_type			type;
	_jc_java_awt_SystemColor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_SystemColor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_SystemColor$refs {
    _jc_java_awt_SystemColor$sub_refs	java_awt_SystemColor;
    _jc_java_awt_Color$sub_refs	java_awt_Color;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_SystemColor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_SystemColor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Color$sub_nonrefs	java_awt_Color;
    _jc_java_awt_SystemColor$sub_nonrefs	java_awt_SystemColor;
};

// Object instance structure
struct _jc_java_awt_SystemColor$object {
	_jc_java_awt_SystemColor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_SystemColor$vtype	*vtype;
	_jc_java_awt_SystemColor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_SystemColor$vtype _jc_java_awt_SystemColor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_SystemColor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_SystemColor$class_object;

#endif	/* _JC_java_awt_SystemColor_H_ */

==> jc-1.4.6.tar.gz: java/awt/SystemColor.h <==
// public final class java.awt.SystemColor

// class file dependencies
// @dep_class 2110d2173833fd4f java_awt_Color
// @dep_class d23b12b037835f06 java_awt_SystemColor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Color

#include "java/awt/Color.h"

#ifndef _JC_java_awt_SystemColor_H_
#define _JC_java_awt_SystemColor_H_

// Forward structure declarations
struct _jc_java_awt_PaintContext$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_SystemColor$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_SystemColor$sub_refs	_jc_java_awt_SystemColor$sub_refs;
typedef struct _jc_java_awt_SystemColor$sub_nonrefs	_jc_java_awt_SystemColor$sub_nonrefs;
typedef struct _jc_java_awt_SystemColor$refs	_jc_java_awt_SystemColor$refs;
typedef struct _jc_java_awt_SystemColor$nonrefs	_jc_java_awt_SystemColor$nonrefs;
typedef struct _jc_java_awt_SystemColor$object	_jc_java_awt_SystemColor$object;

typedef struct _jc_java_awt_SystemColor$fields_struct	_jc_java_awt_SystemColor$fields_struct;
typedef const struct _jc_java_awt_SystemColor$vmethods	_jc_java_awt_SystemColor$vmethods;
typedef const struct _jc_java_awt_SystemColor$vtable	_jc_java_awt_SystemColor$vtable;
typedef const struct _jc_java_awt_SystemColor$vtype	_jc_java_awt_SystemColor$vtype;

// Class fields structure
struct _jc_java_awt_SystemColor$fields_struct {
	struct _jc_java_awt_SystemColor$object	*activeCaption;
	struct _jc_java_awt_SystemColor$object	*activeCaptionBorder;
	struct _jc_java_awt_SystemColor$object	*activeCaptionText;
	_jc_int_array	*colors;
	struct _jc_java_awt_SystemColor$object	*control;
	struct _jc_java_awt_SystemColor$object	*controlDkShadow;
	struct _jc_java_awt_SystemColor$object	*controlHighlight;
	struct _jc_java_awt_SystemColor$object	*controlLtHighlight;
	struct _jc_java_awt_SystemColor$object	*controlShadow;
	struct _jc_java_awt_SystemColor$object	*controlText;
	struct _jc_java_awt_SystemColor$object	*desktop;
	struct _jc_java_awt_SystemColor$object	*inactiveCaption;
	struct _jc_java_awt_SystemColor$object	*inactiveCaptionBorder;
	struct _jc_java_awt_SystemColor$object	*inactiveCaptionText;
	struct _jc_java_awt_SystemColor$object	*info;
	struct _jc_java_awt_SystemColor$object	*infoText;
	struct _jc_java_awt_SystemColor$object	*menu;
	struct _jc_java_awt_SystemColor$object	*menuText;
	struct _jc_java_awt_SystemColor$object	*scrollbar;
	struct _jc_java_awt_SystemColor$object	*text;
	struct _jc_java_awt_SystemColor$object	*textHighlight;
	struct _jc_java_awt_SystemColor$object	*textHighlightText;
	struct _jc_java_awt_SystemColor$object	*textInactiveText;
	struct _jc_java_awt_SystemColor$object	*textText;
	struct _jc_java_awt_SystemColor$object	*window;
	struct _jc_java_awt_SystemColor$object	*windowBorder;
	struct _jc_java_awt_SystemColor$object	*windowText;
	jlong	serialVersionUID;
	jint	ACTIVE__5fCAPTION;
	jint	ACTIVE__5fCAPTION__5fBORDER;
	jint	ACTIVE__5fCAPTION__5fTEXT;
	jint	CONTROL;
	jint	CONTROL__5fDK__5fSHADOW;
	jint	CONTROL__5fHIGHLIGHT;
	jint	CONTROL__5fLT__5fHIGHLIGHT;
	jint	CONTROL__5fSHADOW;
	jint	CONTROL__5fTEXT;
	jint	DESKTOP;
	jint	INACTIVE__5fCAPTION;
	jint	INACTIVE__5fCAPTION__5fBORDER;
	jint	INACTIVE__5fCAPTION__5fTEXT;
	jint	INFO;
	jint	INFO__5fTEXT;
	jint	MENU;
	jint	MENU__5fTEXT;
	jint	NUM__5fCOLORS;
	jint	SCROLLBAR;
	jint	TEXT;
	jint	TEXT__5fHIGHLIGHT;
	jint	TEXT__5fHIGHLIGHT__5fTEXT;
	jint	TEXT__5fINACTIVE__5fTEXT;
	jint	TEXT__5fTEXT;
	jint	WINDOW;
	jint	WINDOW__5fBORDER;
	jint	WINDOW__5fTEXT;
};
extern _jc_java_awt_SystemColor$fields_struct _jc_java_awt_SystemColor$class_fields;

// Constructors
extern void _jc_java_awt_SystemColor$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_SystemColor$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_SystemColor$method$createContext$a690f44ea9ada11b(_jc_env *, struct _jc_java_awt_SystemColor$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_SystemColor$method$getRGB$2afffecc5c382bc6(_jc_env *, struct _jc_java_awt_SystemColor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_SystemColor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_SystemColor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_SystemColor$method_info$createContext$a690f44ea9ada11b;
extern _jc_method _jc_java_awt_SystemColor$method_info$getRGB$2afffecc5c382bc6;
extern _jc_method _jc_java_awt_SystemColor$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_awt_SystemColor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_SystemColor$vmethods {
	struct _jc_object	*(*createContext$a690f44ea9ada11b)(_jc_env *, struct _jc_java_awt_SystemColor$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Rectangle$object *, struct _jc_java_awt_geom_Rectangle2D$object *, struct _jc_java_awt_geom_AffineTransform$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
	jint	(*getRGB$2afffecc5c382bc6)(_jc_env *, struct _jc_java_awt_SystemColor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_SystemColor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_SystemColor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Color$vmethods	java_awt_Color;
	_jc_java_awt_SystemColor$vmethods	java_awt_SystemColor;
};

// Vtype
struct _jc_java_awt_SystemColor$vtype {
	_jc_type			type;
	_jc_java_awt_SystemColor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_SystemColor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_SystemColor$refs {
    _jc_java_awt_SystemColor$sub_refs	java_awt_SystemColor;
    _jc_java_awt_Color$sub_refs	java_awt_Color;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_SystemColor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_SystemColor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Color$sub_nonrefs	java_awt_Color;
    _jc_java_awt_SystemColor$sub_nonrefs	java_awt_SystemColor;
};

// Object instance structure
struct _jc_java_awt_SystemColor$object {
	_jc_java_awt_SystemColor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_SystemColor$vtype	*vtype;
	_jc_java_awt_SystemColor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_SystemColor$vtype _jc_java_awt_SystemColor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_SystemColor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_SystemColor$class_object;

#endif	/* _JC_java_awt_SystemColor_H_ */
